#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-6trM4C6UP334075uQ6ZEVA
key:                  haskell-language-server-2.3.0.0-6trM4C6UP334075uQ6ZEVA
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  3d35edcc36c3103784de4275f3905a83
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-6trM4C6UP334075uQ6ZEVA
depends:
    aeson-pretty-0.8.10-CtOF5yzA90t5fWHc997lbJ
    async-2.2.6-JFqXkyZWakA6MSvky6jlwB base-4.18.2.1
    base16-bytestring-1.0.2.0-8g6yC3fsg2K6nyARuCXVuM
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-5HTqHLT0Zf4Acm8DXUaDG1
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-GG4oQL1Pbvk2YReVs3ucdi filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-DLn43Ul2XF9BhzC7AGbKob
    githash-0.1.6.3-GUPPgRbB6OuEbmCcGv8KZB
    hie-bios-0.12.0-7wMlOF17eexL5h7CRXf36U
    hiedb-0.4.3.0-2B7vm1Eb57pDjxvRObkxot
    hls-alternate-number-format-plugin-2.3.0.0-Ij3tLRZQKqIDLPrIzGNTqy
    hls-cabal-fmt-plugin-2.3.0.0-HL4QvgbcE3U573BahjpTgP
    hls-cabal-plugin-2.3.0.0-6fl257WQWMV9CfziislfGc
    hls-call-hierarchy-plugin-2.3.0.0-G9K8LfbmLMq648TwsEwy6z
    hls-change-type-signature-plugin-2.3.0.0-5l9BkBITezSHPB4TKoBc2G
    hls-class-plugin-2.3.0.0-CwcBIs57YHmsuMcyllZWx
    hls-code-range-plugin-2.3.0.0-HX6G19hYFMoF3TJwQiuBAa
    hls-eval-plugin-2.3.0.0-LSmRBQi44es98TLQq4r9R
    hls-explicit-fixity-plugin-2.3.0.0-Gz4pFYMj8gW8Kqn15tNHxn
    hls-explicit-imports-plugin-2.3.0.0-4n9kE2WDniU9cDJ13Y2VUi
    hls-explicit-record-fields-plugin-2.3.0.0-1eO8XalbRsz9JCoq2XjHHy
    hls-fourmolu-plugin-2.3.0.0-DpO9QXs6ftlDLCJGFKQWvE
    hls-gadt-plugin-2.3.0.0-1OSFR8VkEwyb72bhvsvZ
    hls-graph-2.3.0.0-1B5GSgbN5tgFODBfL8MjR9
    hls-hlint-plugin-2.3.0.0-DKgHlG0HfRECt2rwHMVXzr
    hls-module-name-plugin-2.3.0.0-EPeBz4tIsA3JSXNvw823pd
    hls-ormolu-plugin-2.3.0.0-2tm8BnGeeeRIs7lcild2nT
    hls-overloaded-record-dot-plugin-2.3.0.0-74vJpBmrIF2ILwbl2YTEIZ
    hls-plugin-api-2.3.0.0-HZFnlB4uroEI1syiyMmKGx
    hls-pragmas-plugin-2.3.0.0-9DWkjeMJ1meIVJfSvp29gP
    hls-qualify-imported-names-plugin-2.3.0.0-HZYx3UXDb5cIs0FBWw09rg
    hls-refactor-plugin-2.3.0.0-FmJENG1Dam75pPvO2d6CW0
    hls-rename-plugin-2.3.0.0-IolBMX7FwTvDpqFlfDHygy
    hls-retrie-plugin-2.3.0.0-2pRWnz6PCAf6GSHT3zXv3S
    hls-splice-plugin-2.3.0.0-2FXiJTQ7mlQ1XhJ4oOEx7S
    hls-stylish-haskell-plugin-2.3.0.0-41hBP0fNH5C19ZGCcwdAu
    lsp-2.2.0.0-3J7slxQP1ui8QijUPoiGpE
    optparse-applicative-0.18.1.0-64q3Zt8gfMnAm6zpFRaIVN
    optparse-simple-0.1.1.4-ESvrdS04hm5LXhM2i0Blkm
    prettyprinter-1.7.1-LD9ksSCydFQDqbwXyaukvW process-1.6.19.0
    safe-exceptions-0.1.7.4-AUKG3QHTD7NLfABqrCKWM8
    sqlite-simple-0.4.19.0-E0yyMyfgc7hJmZGvlGU993 text-2.0.2
    unordered-containers-0.2.20.1-9qHVoc2smYt9flJ6feRxGY

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

